.. _spider_theoatmeal.com:

theoatmeal.com
--------------
Comics and blog posts from `The Oatmeal <https://theoatmeal.com>`_.

Configuration
~~~~~~~~~~~~~
Add ``theoatmeal.com`` to the list of spiders:

.. code-block:: ini

   # List of spiders to run by default, one per line.
   spiders =
     theoatmeal.com

